@@ -21,9 +21,9 @@ See the README file for the full documentation, avilable at
 """
 
 __title__ = 'internetarchive'
-__version__ = '0.2.7'
+__version__ = '0.2.8'
 __author__ = 'Jacob M. Johnson'
 __license__ = 'GPL'
 __copyright__ = 'Copyright 2013 Jacob M. Johnson'
 
-from .internetarchive import Item, File, Catalog, Search
+from .internetarchive import Item, File, Catalog, Search, Mine
